@@ -24,22 +24,28 @@
 
 #include <Lum/Model/Action.h>
 #include <Lum/Model/String.h>
+#include <Lum/Model/Selection.h>
+#include <Lum/Model/Table.h>
 #include <Lum/Model/Tree.h>
 
-#include <Lum/Tree.h>
+#include <Lum/Table.h>
 
 #include "Configuration.h"
 
+typedef Lum::Model::StdTable<Formula*>     FormulaModel;
+typedef Lum::Base::Reference<FormulaModel> FormulaModelRef;
+
 class FormulaCalc : public Lum::Component, public ConfigPlugin
 {
 private:
-  Lum::Model::ActionRef selectAction;
-  Lum::Model::ActionRef executeAction;
-  Lum::Model::TreeRef   functions;
-  Lum::Model::StringRef notation;
-  Lum::Model::StringRef description;
-
-  Lum::Tree             *tree;
+  Lum::Model::ActionRef              selectAction;
+  Lum::Model::ActionRef              executeAction;
+  Lum::Model::SizeTRef               category;
+  Lum::Model::SizeTRef               subCategory;
+  Lum::Model::StringTableRef         categories;
+  Lum::Model::StringTableRef         subCategories;
+  FormulaModelRef                    functions;
+  Lum::Model::SingleLineSelectionRef function;
 
 public:
   FormulaCalc();
